@@ -3,14 +3,19 @@ import socket
 from flib.host import Host
 from flib import lst2cmd
 from flib import ok_sh
+from flib import abort
+from flib import check_result
 from flib import ShellResult
+from flib.env import args as global_args
+from flib.output import configure_logger
+log = configure_logger('localhost')
 
 def sh2res(r):
     return ShellResult(lst2cmd(r.cmd), r.call_args['cwd'], r.stdout, r.stderr, r.exit_code)
 
 class LocalHost(Host):
 
-    def __init__(self):
+    def __init__(self, *args, **kwd):
         self._bash = ok_sh.bash.bake('-l', '-c')
         self._cp = ok_sh.cp.bake('-v')
         self.user = os.getlogin()
@@ -18,13 +23,27 @@ class LocalHost(Host):
         self.login = '%s@%s' % (self.user, self.name)
 
     def _sh(self, cwd, *args):
-        result = sh2res(self._bash(lst2cmd(args), _cwd=cwd))
-        assert result.exit_code == 0
+        try:
+            shres = self._bash(lst2cmd(args), _cwd=cwd)
+        except Exception, ex:
+            if global_args.cmds == 'abort':
+                abort(log, ex)
+            elif global_args.cmds == 'warn':
+                log.error(ex)
+        result = sh2res(shres)
+        check_result(result, global_args.cmds, log)
         return result
 
     def handle_command(self, *args):
-        result = sh2res(self._bash(lst2cmd(args)))
-        assert result.exit_code == 0
+        try:
+            shres = self._bash(lst2cmd(args))
+        except Exception, ex:
+            if global_args.cmds == 'abort':
+                abort(log, ex)
+            elif global_args.cmds == 'warn':
+                log.error(ex)
+        result = sh2res(shres)
+        check_result(result, global_args.cmds, log)
         return result
 
     #def run(self, command):
